aboutsummaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorJose Luis Duran <jlduran@FreeBSD.org>2026-01-24 02:06:57 +0000
committerJose Luis Duran <jlduran@FreeBSD.org>2026-01-24 02:06:57 +0000
commitcd730bef74f9ecc2500fd5c01094dd5bfd34c246 (patch)
treea6893398fdb70dd8182a88c3b58d8dd49bb665e5 /tools
parent202e3109a9d6699cf78e83f9047cefeb07659767 (diff)
Diffstat (limited to 'tools')
-rwxr-xr-xtools/tools/nanobsd/defaults.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/tools/nanobsd/defaults.sh b/tools/tools/nanobsd/defaults.sh
index a0a186cee42f..31f3df9a3086 100755
--- a/tools/tools/nanobsd/defaults.sh
+++ b/tools/tools/nanobsd/defaults.sh
@@ -554,8 +554,8 @@ run_late_customize() {
#
fixup_before_diskimage() {
# Run the deduplication script that takes the metalog journal and
# combines multiple entries for the same file (see source for
# details). We take the extra step of removing the size keywords. This
# script, and many of the user scripts, copies, appends and otherwise
# modifies files in the build, changing their sizes. These actions are
# impossible to trap, so go ahead remove the size= keyword. For this
@@ -566,7 +566,7 @@ fixup_before_diskimage() {
cp ${NANO_METALOG} ${NANO_METALOG}.pre
echo "/set uname=${NANO_DEF_UNAME} gname=${NANO_DEF_GNAME}" > ${NANO_METALOG}
cat ${NANO_METALOG}.pre | ${NANO_TOOLS}/mtree-dedup.awk | \
- sed -e 's/ size=[0-9][0-9]*//' | sort >> ${NANO_METALOG}
+ sort -u | mtree -C -K uname,gname,tags -R size,time >> ${NANO_METALOG}
fi
}
@@ -554,8 +554,8 @@ run_late_customize() {
fixup_before_diskimage() {
# Run the deduplication script that takes the metalog journal and
- # combines multiple entries for the same file (see source for
- # details). We take the extra step of removing the size keywords. This
+ # combines multiple entries for the same file (see source for details).
+ # We take the extra step of removing the size and time keywords. This
# script, and many of the user scripts, copies, appends and otherwise
# modifies files in the build, changing their sizes. These actions are